@@ -44,7 +44,7 @@ class InterpreterNotFound(OSError):
 
 
 class ProcessEnv:
-    """A environment with a 'bin' directory and a set of 'env' vars."""
+    """An environment with a 'bin' directory and a set of 'env' vars."""
 
     location: str
 
@@ -69,7 +69,7 @@ class ProcessEnv:
 
         if self.bin_paths:
             self.env["PATH"] = os.pathsep.join(
-                self.bin_paths + [self.env.get("PATH", "")]
+                [*self.bin_paths, self.env.get("PATH", "")]
             )
 
     @property
@@ -264,10 +264,7 @@ class CondaEnv(ProcessEnv):
         # Ensure the pip package is installed.
         cmd.append("pip")
 
-        if self.interpreter:
-            python_dep = f"python={self.interpreter}"
-        else:
-            python_dep = "python"
+        python_dep = f"python={self.interpreter}" if self.interpreter else "python"
         cmd.append(python_dep)
 
         logger.info(f"Creating conda env in {self.location_name} with {python_dep}")
