@@ -23,14 +23,16 @@ from textwrap import dedent
 from typing import NamedTuple
 from unittest import mock
 
-import py
 import pytest
+import virtualenv
+from packaging import version
 
 import nox.virtualenv
 
 IS_WINDOWS = nox.virtualenv._SYSTEM == "Windows"
 HAS_CONDA = shutil.which("conda") is not None
 RAISE_ERROR = "RAISE_ERROR"
+VIRTUALENV_VERSION = virtualenv.version.version
 
 
 class TextProcessResult(NamedTuple):
@@ -149,7 +151,7 @@ def test_condaenv_create(make_conda):
     venv.create()
     assert not dir_.join("test.txt").check()
 
-    # Test running create on an existing environment with reuse_exising
+    # Test running create on an existing environment with reuse_existing
     # enabled, it should not be deleted.
     dir_.ensure("test.txt")
     assert dir_.join("test.txt").check()
@@ -347,7 +349,7 @@ def test_create(monkeypatch, make_one):
     venv.create()
     assert not dir_.join("test.txt").check()
 
-    # Test running create on an existing environment with reuse_exising
+    # Test running create on an existing environment with reuse_existing
     # enabled, it should not be deleted.
     dir_.ensure("test.txt")
     assert dir_.join("test.txt").check()
@@ -473,6 +475,33 @@ def test_create_reuse_oldstyle_virtualenv_environment(make_one):
 
 
 @enable_staleness_check
+@pytest.mark.skipif(IS_WINDOWS, reason="Avoid 'No pyvenv.cfg file' error on Windows.")
+def test_inner_functions_reusing_venv(make_one):
+    venv, location = make_one(reuse_existing=True)
+    venv.create()
+
+    # Drop a venv-style pyvenv.cfg into the environment.
+    pyvenv_cfg = """\
+    home = /usr/bin
+    include-system-site-packages = false
+    version = 3.10
+    base-prefix = foo
+    """
+    location.join("pyvenv.cfg").write(dedent(pyvenv_cfg))
+
+    base_prefix = venv._read_base_prefix_from_pyvenv_cfg()
+    assert base_prefix == "foo"
+
+    reused_interpreter = venv._check_reused_environment_interpreter()
+    # The created won't match 'foo'
+    assert not reused_interpreter
+
+
+@enable_staleness_check
+@pytest.mark.skipif(
+    version.parse(VIRTUALENV_VERSION) >= version.parse("20.22.0"),
+    reason="Python 2.7 unsupported for virtualenv>=20.22.0",
+)
 def test_create_reuse_python2_environment(make_one):
     venv, location = make_one(reuse_existing=True, interpreter="2.7")
 
@@ -675,16 +704,14 @@ def test__resolved_interpreter_windows_path_and_version_fails(
 
 
 @mock.patch("nox.virtualenv._SYSTEM", new="Windows")
-@mock.patch.object(py._path.local.LocalPath, "check")
 @mock.patch.object(shutil, "which")
-def test__resolved_interpreter_not_found(which, check, make_one):
+def test__resolved_interpreter_not_found(which, make_one):
     # Establish that if an interpreter cannot be found at a standard
     # location on Windows, we raise a useful error.
     venv, _ = make_one(interpreter="python3.6")
 
     # We are on Windows, and nothing can be found.
     which.return_value = None
-    check.return_value = False
 
     # Run the test.
     with pytest.raises(nox.virtualenv.InterpreterNotFound):
